{system_name} Был получен запрос на сброс пароля

Привет, {name},

Мы заметили, что у вас возникли проблемы с доступом к учетной записи из-за забытого пароля.

Был получен запрос на сброс пароля, связанного с вашей учетной записью.

Чтобы продолжить процесс сброса пароля, просто нажмите на кнопку ниже:

Сбросить пароль

Если кнопка не работает, вы можете вручную скопировать и вставить следующий URL в адресную строку вашего веб-браузера:

https://devint.alif.tj/login/newpassword/{code}

С наилучшими пожеланиями,

Команда AlifTech